# 蚂蚁租赁业务流程梳理

> 根据项目需求，裁剪官方部分流程（官方多流程处理时），按照项目具体需求按需选取

## 1. 前置订单签约

### 1.1 发起合同签约

```mermaid
    sequenceDiagram
    Actor u as 新老系统
    participant p as 统一支付平台
    participant a as 蚂蚁

    note over u,a: 签约流程【前置订单签约】

    p->>a: 同步前置订单

    p->>a: 发起前置合同签署

    p->>a:  发起代扣签约请求

    p->>a:  查询代扣签约结果

    p->>a:  代扣签约完成后，落签合同

    p->>a:  如果需要多方落签的情况


```

### 1.1.1 发起代扣签约

> 归属于具体订单

```mermaid
    sequenceDiagram
    Actor u as 新老系统
    participant p as 统一支付平台
    participant a as 蚂蚁


    u->>+p: 发起代扣签约请求

    p->>+p: 开始组装请求

    p->>p: 填写订单号

    p->>-p: 组装请求完成

    p->>+a: 发送代扣签约请求

    a-->>-p: 响应代扣签约结果
    p->>-u:  响应代扣签约结果



```

### 1.1.2 发起解除代扣

> 归属于具体订单

```mermaid
    sequenceDiagram
    Actor u as 新老系统
    participant p as 统一支付平台
    participant a as 蚂蚁

    u->>+p: 发起解除代扣请求

    p->>+p: 开始组装请求

    p->>p: 填写订单号

    p->>-p: 组装请求完成

    p->>+a: 发送解除代扣请求

    a-->>-p: 响应解除结果
    p->>-u:  响应解除结果

```

### 1.1.3 查询代扣签约

> 归属于具体订单

```mermaid
    sequenceDiagram
    Actor u as 新老系统
    participant p as 统一支付平台
    participant a as 蚂蚁


    u->>+p: 发起查询代扣签约请求

    p->>+p: 开始组装请求

    p->>p: 填写订单号

    p->>-p: 组装请求完成

    p->>+a: 发送查询代扣签约请求

    a-->>-p: 响应查询代扣签约结果
    p->>-u:  响应查询代扣签约结果



```

### 1.1.4 取消代扣计划

> 归属于具体订单

```mermaid
    sequenceDiagram
    Actor u as 新老系统
    participant p as 统一支付平台
    participant a as 蚂蚁


    u->>+p: 发起取消代扣签约请求
    p->>+p: 开始组装请求

    p->>p: 填写订单号
    p->>p: 填写取消理由

    p->>-p: 组装请求完成
    p->>+a: 发送取消代扣签约请求

    a-->>-p: 响应取消代扣签约结果
    p->>-u:  响应取消代扣签约结果



```

### 1.1.5 异步解约确认

> 归属于具体订单

```mermaid
    sequenceDiagram
    Actor u as 新老系统
    participant p as 统一支付平台
    participant a as 蚂蚁


    u->>+p: 发起异步解约确认请求
    p->>+p: 开始组装请求

    p->>p: 填写订单号
    p->>p: 填写操作 == "REFUSE"
    p->>p: 填写 服务用户
    p->>p: 填写 用户欠款
    p->>p: 填写 解约理由


    p->>-p: 组装请求完成
    p->>+a: 发送异步解约确认请求

    a-->>-p: 响应异步解约确认结果
    p->>-u:  响应异步解约确认结果



```

### 1.1.6 查询订单信息

> 归属于具体订单

```mermaid
    sequenceDiagram
    Actor u as 新老系统
    participant p as 统一支付平台
    participant a as 蚂蚁


    u->>+p: 发起查询订单信息请求
    p->>+p: 开始组装请求

    p->>p: 填写 查询类型("orderFullInfo")
    p->>p: 填写 订单号


    p->>-p: 组装请求完成
    p->>+a: 发送查询订单信息请求

    a-->>-p: 响应查询订单信息结果
    p->>-u:  响应查询订单信息结果


```

### 1.11.1 同步前置订单

```mermaid
    sequenceDiagram

    participant p as 统一支付平台
    participant a as 蚂蚁



    p->>+p: 开始组装请求

    p->>p: 填写 查询类型("orderFullInfo")
    p->>p: 填写 订单号


    note left of p: 这样填写数据, 订单更类似我们统一支付平台的合约概念
    p->>p: 填写  租赁期数
    p->>p: 填写 总金额

    p->>-p: 组装请求完成
    p->>+a: 发送查询订单信息请求

    a-->>-p: 响应查询订单信息结果



```

### 1.9.1 关闭订单

> 归属于具体订单
>
> 关闭订单的前提：
>
> 1. 用户履约完成
> 2. 取消代扣计划：场景
>    2.1 租转售  
>    2.2 退租成功

```mermaid
    sequenceDiagram

    Actor u as 新老系统
    participant p as 统一支付平台
    participant a as 蚂蚁


    u->>+p: 发起关闭订单请求

    p->>+p: 开始组装交易同步请求
    p->>p: 填写订单号, 关闭原因
    p->>-p: 组装交易同步请求完成

    p->>+a: 发送关闭订单请求
    a-->>-p: 响应关闭结果



    p->>-u:  响应关闭结果




```

## 2. 合约

### 2.1 签约

> 前置签约模式

```mermaid
    sequenceDiagram
    Actor u as 新老系统
    participant p as 统一支付平台
    participant a as 蚂蚁

    u->>p: 签署合同请求
    p ->>+a: 发起合同申请

    p ->>a: 调用前置签约合同接口
    p ->>a: 填写参数 合同模板ID、订单ID【统一平台的合约ID】

    a->>a: 合同校验
    a->>p: 合同校验完成后，返回签约链接地址
    p->>u: 透传签约链接，在用户界面拉起合同界面
    u->>a: 签署合同完毕

    a ->>-p: 完成合同签约


```
